@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # shellcheck disable=SC2034
-export source="${BASH_SOURCE[0]}"; debug.sh source
+export starting="${BASH_SOURCE[0]}"; debug.sh starting
 
 test -n "${PROJECT_BASHRC}" || { error.sh "PROJECT_BASHRC" "empty"; exit 1; }
 
@@ -9,4 +9,4 @@ deactivate > /dev/null 2>&1
 
 project-upgrade.sh "$( basename "${PROJECT_BASHRC}" )" || exit 1
 
-unset source
+unset starting
